print("import: 'django'")
import django

print("import: 'django.apps'")
import django.apps

print("import: 'django.conf'")
import django.conf

print("import: 'django.conf.app_template.migrations'")
import django.conf.app_template.migrations

print("import: 'django.conf.locale'")
import django.conf.locale

print("import: 'django.conf.locale.ar'")
import django.conf.locale.ar

print("import: 'django.conf.locale.az'")
import django.conf.locale.az

print("import: 'django.conf.locale.bg'")
import django.conf.locale.bg

print("import: 'django.conf.locale.bn'")
import django.conf.locale.bn

print("import: 'django.conf.locale.bs'")
import django.conf.locale.bs

print("import: 'django.conf.locale.ca'")
import django.conf.locale.ca

print("import: 'django.conf.locale.cs'")
import django.conf.locale.cs

print("import: 'django.conf.locale.cy'")
import django.conf.locale.cy

print("import: 'django.conf.locale.da'")
import django.conf.locale.da

print("import: 'django.conf.locale.de'")
import django.conf.locale.de

print("import: 'django.conf.locale.de_CH'")
import django.conf.locale.de_CH

print("import: 'django.conf.locale.el'")
import django.conf.locale.el

print("import: 'django.conf.locale.en'")
import django.conf.locale.en

print("import: 'django.conf.locale.en_AU'")
import django.conf.locale.en_AU

print("import: 'django.conf.locale.en_GB'")
import django.conf.locale.en_GB

print("import: 'django.conf.locale.eo'")
import django.conf.locale.eo

print("import: 'django.conf.locale.es'")
import django.conf.locale.es

print("import: 'django.conf.locale.es_AR'")
import django.conf.locale.es_AR

print("import: 'django.conf.locale.es_CO'")
import django.conf.locale.es_CO

print("import: 'django.conf.locale.es_MX'")
import django.conf.locale.es_MX

print("import: 'django.conf.locale.es_NI'")
import django.conf.locale.es_NI

print("import: 'django.conf.locale.es_PR'")
import django.conf.locale.es_PR

print("import: 'django.conf.locale.et'")
import django.conf.locale.et

print("import: 'django.conf.locale.eu'")
import django.conf.locale.eu

print("import: 'django.conf.locale.fa'")
import django.conf.locale.fa

print("import: 'django.conf.locale.fi'")
import django.conf.locale.fi

print("import: 'django.conf.locale.fr'")
import django.conf.locale.fr

print("import: 'django.conf.locale.fy'")
import django.conf.locale.fy

print("import: 'django.conf.locale.ga'")
import django.conf.locale.ga

print("import: 'django.conf.locale.gd'")
import django.conf.locale.gd

print("import: 'django.conf.locale.gl'")
import django.conf.locale.gl

print("import: 'django.conf.locale.he'")
import django.conf.locale.he

print("import: 'django.conf.locale.hi'")
import django.conf.locale.hi

print("import: 'django.conf.locale.hr'")
import django.conf.locale.hr

print("import: 'django.conf.locale.hu'")
import django.conf.locale.hu

print("import: 'django.conf.locale.id'")
import django.conf.locale.id

print("import: 'django.conf.locale.it'")
import django.conf.locale.it

print("import: 'django.conf.locale.ja'")
import django.conf.locale.ja

print("import: 'django.conf.locale.ka'")
import django.conf.locale.ka

print("import: 'django.conf.locale.km'")
import django.conf.locale.km

print("import: 'django.conf.locale.kn'")
import django.conf.locale.kn

print("import: 'django.conf.locale.ko'")
import django.conf.locale.ko

print("import: 'django.conf.locale.lt'")
import django.conf.locale.lt

print("import: 'django.conf.locale.lv'")
import django.conf.locale.lv

print("import: 'django.conf.locale.mk'")
import django.conf.locale.mk

print("import: 'django.conf.locale.ml'")
import django.conf.locale.ml

print("import: 'django.conf.locale.mn'")
import django.conf.locale.mn

print("import: 'django.conf.locale.nb'")
import django.conf.locale.nb

print("import: 'django.conf.locale.nl'")
import django.conf.locale.nl

print("import: 'django.conf.locale.nn'")
import django.conf.locale.nn

print("import: 'django.conf.locale.pl'")
import django.conf.locale.pl

print("import: 'django.conf.locale.pt'")
import django.conf.locale.pt

print("import: 'django.conf.locale.pt_BR'")
import django.conf.locale.pt_BR

print("import: 'django.conf.locale.ro'")
import django.conf.locale.ro

print("import: 'django.conf.locale.ru'")
import django.conf.locale.ru

print("import: 'django.conf.locale.sk'")
import django.conf.locale.sk

print("import: 'django.conf.locale.sl'")
import django.conf.locale.sl

print("import: 'django.conf.locale.sq'")
import django.conf.locale.sq

print("import: 'django.conf.locale.sr'")
import django.conf.locale.sr

print("import: 'django.conf.locale.sr_Latn'")
import django.conf.locale.sr_Latn

print("import: 'django.conf.locale.sv'")
import django.conf.locale.sv

print("import: 'django.conf.locale.ta'")
import django.conf.locale.ta

print("import: 'django.conf.locale.te'")
import django.conf.locale.te

print("import: 'django.conf.locale.th'")
import django.conf.locale.th

print("import: 'django.conf.locale.tr'")
import django.conf.locale.tr

print("import: 'django.conf.locale.uk'")
import django.conf.locale.uk

print("import: 'django.conf.locale.vi'")
import django.conf.locale.vi

print("import: 'django.conf.locale.zh_Hans'")
import django.conf.locale.zh_Hans

print("import: 'django.conf.locale.zh_Hant'")
import django.conf.locale.zh_Hant

print("import: 'django.conf.urls'")
import django.conf.urls

print("import: 'django.contrib'")
import django.contrib

print("import: 'django.contrib.admin'")
import django.contrib.admin

print("import: 'django.contrib.admin.migrations'")
import django.contrib.admin.migrations

print("import: 'django.contrib.admin.templatetags'")
import django.contrib.admin.templatetags

print("import: 'django.contrib.admin.views'")
import django.contrib.admin.views

print("import: 'django.contrib.admindocs'")
import django.contrib.admindocs

print("import: 'django.contrib.auth'")
import django.contrib.auth

print("import: 'django.contrib.auth.handlers'")
import django.contrib.auth.handlers

print("import: 'django.contrib.auth.management'")
import django.contrib.auth.management

print("import: 'django.contrib.auth.management.commands'")
import django.contrib.auth.management.commands

print("import: 'django.contrib.auth.migrations'")
import django.contrib.auth.migrations

print("import: 'django.contrib.contenttypes'")
import django.contrib.contenttypes

print("import: 'django.contrib.contenttypes.management'")
import django.contrib.contenttypes.management

print("import: 'django.contrib.contenttypes.management.commands'")
import django.contrib.contenttypes.management.commands

print("import: 'django.contrib.contenttypes.migrations'")
import django.contrib.contenttypes.migrations

print("import: 'django.contrib.flatpages'")
import django.contrib.flatpages

print("import: 'django.contrib.flatpages.migrations'")
import django.contrib.flatpages.migrations

print("import: 'django.contrib.flatpages.templatetags'")
import django.contrib.flatpages.templatetags

print("import: 'django.contrib.gis'")
import django.contrib.gis

print("import: 'django.contrib.gis.db'")
import django.contrib.gis.db

print("import: 'django.contrib.gis.db.backends'")
import django.contrib.gis.db.backends

print("import: 'django.contrib.gis.db.backends.base'")
import django.contrib.gis.db.backends.base

print("import: 'django.contrib.gis.db.backends.mysql'")
import django.contrib.gis.db.backends.mysql

print("import: 'django.contrib.gis.db.backends.oracle'")
import django.contrib.gis.db.backends.oracle

print("import: 'django.contrib.gis.db.backends.postgis'")
import django.contrib.gis.db.backends.postgis

print("import: 'django.contrib.gis.db.backends.spatialite'")
import django.contrib.gis.db.backends.spatialite

print("import: 'django.contrib.gis.geometry'")
import django.contrib.gis.geometry

print("import: 'django.contrib.gis.management'")
import django.contrib.gis.management

print("import: 'django.contrib.gis.management.commands'")
import django.contrib.gis.management.commands

print("import: 'django.contrib.gis.serializers'")
import django.contrib.gis.serializers

print("import: 'django.contrib.humanize'")
import django.contrib.humanize

print("import: 'django.contrib.humanize.templatetags'")
import django.contrib.humanize.templatetags

print("import: 'django.contrib.messages'")
import django.contrib.messages

print("import: 'django.contrib.messages.storage'")
import django.contrib.messages.storage

print("import: 'django.contrib.postgres'")
import django.contrib.postgres

print("import: 'django.contrib.postgres.forms'")
import django.contrib.postgres.forms

print("import: 'django.contrib.redirects'")
import django.contrib.redirects

print("import: 'django.contrib.redirects.migrations'")
import django.contrib.redirects.migrations

print("import: 'django.contrib.sessions'")
import django.contrib.sessions

print("import: 'django.contrib.sessions.backends'")
import django.contrib.sessions.backends

print("import: 'django.contrib.sessions.management'")
import django.contrib.sessions.management

print("import: 'django.contrib.sessions.management.commands'")
import django.contrib.sessions.management.commands

print("import: 'django.contrib.sessions.migrations'")
import django.contrib.sessions.migrations

print("import: 'django.contrib.sitemaps'")
import django.contrib.sitemaps

print("import: 'django.contrib.sitemaps.management'")
import django.contrib.sitemaps.management

print("import: 'django.contrib.sitemaps.management.commands'")
import django.contrib.sitemaps.management.commands

print("import: 'django.contrib.sites'")
import django.contrib.sites

print("import: 'django.contrib.sites.migrations'")
import django.contrib.sites.migrations

print("import: 'django.contrib.staticfiles'")
import django.contrib.staticfiles

print("import: 'django.contrib.staticfiles.management'")
import django.contrib.staticfiles.management

print("import: 'django.contrib.staticfiles.management.commands'")
import django.contrib.staticfiles.management.commands

print("import: 'django.contrib.staticfiles.templatetags'")
import django.contrib.staticfiles.templatetags

print("import: 'django.contrib.syndication'")
import django.contrib.syndication

print("import: 'django.core'")
import django.core

print("import: 'django.core.cache'")
import django.core.cache

print("import: 'django.core.cache.backends'")
import django.core.cache.backends

print("import: 'django.core.checks'")
import django.core.checks

print("import: 'django.core.checks.compatibility'")
import django.core.checks.compatibility

print("import: 'django.core.checks.security'")
import django.core.checks.security

print("import: 'django.core.files'")
import django.core.files

print("import: 'django.core.handlers'")
import django.core.handlers

print("import: 'django.core.mail'")
import django.core.mail

print("import: 'django.core.mail.backends'")
import django.core.mail.backends

print("import: 'django.core.management'")
import django.core.management

print("import: 'django.core.management.commands'")
import django.core.management.commands

print("import: 'django.core.serializers'")
import django.core.serializers

print("import: 'django.core.servers'")
import django.core.servers

print("import: 'django.db'")
import django.db

print("import: 'django.db.backends'")
import django.db.backends

print("import: 'django.db.backends.base'")
import django.db.backends.base

print("import: 'django.db.backends.dummy'")
import django.db.backends.dummy

print("import: 'django.db.backends.mysql'")
import django.db.backends.mysql

print("import: 'django.db.backends.oracle'")
import django.db.backends.oracle

print("import: 'django.db.backends.postgresql'")
import django.db.backends.postgresql

print("import: 'django.db.backends.postgresql_psycopg2'")
import django.db.backends.postgresql_psycopg2

print("import: 'django.db.backends.sqlite3'")
import django.db.backends.sqlite3

print("import: 'django.db.migrations'")
import django.db.migrations

print("import: 'django.db.migrations.operations'")
import django.db.migrations.operations

print("import: 'django.db.models'")
import django.db.models

print("import: 'django.db.models.fields'")
import django.db.models.fields

print("import: 'django.db.models.functions'")
import django.db.models.functions

print("import: 'django.db.models.sql'")
import django.db.models.sql

print("import: 'django.dispatch'")
import django.dispatch

print("import: 'django.forms'")
import django.forms

print("import: 'django.http'")
import django.http

print("import: 'django.middleware'")
import django.middleware

print("import: 'django.template'")
import django.template

print("import: 'django.template.backends'")
import django.template.backends

print("import: 'django.template.loaders'")
import django.template.loaders

print("import: 'django.templatetags'")
import django.templatetags

print("import: 'django.test'")
import django.test

print("import: 'django.urls'")
import django.urls

print("import: 'django.utils'")
import django.utils

print("import: 'django.utils.translation'")
import django.utils.translation

print("import: 'django.views'")
import django.views

print("import: 'django.views.decorators'")
import django.views.decorators

print("import: 'django.views.generic'")
import django.views.generic

